swift_scality_backend package
=============================

Submodules
----------

swift_scality_backend.diskfile module
-------------------------------------

.. automodule:: swift_scality_backend.diskfile
    :members:
    :undoc-members:
    :show-inheritance:

swift_scality_backend.http_utils module
---------------------------------------

.. automodule:: swift_scality_backend.http_utils
    :members:
    :undoc-members:
    :show-inheritance:

swift_scality_backend.policy_configuration module
-------------------------------------------------

.. automodule:: swift_scality_backend.policy_configuration
    :members:
    :undoc-members:
    :show-inheritance:

swift_scality_backend.server module
-----------------------------------

.. automodule:: swift_scality_backend.server
    :members:
    :undoc-members:
    :show-inheritance:

swift_scality_backend.splice_utils module
-----------------------------------------

.. automodule:: swift_scality_backend.splice_utils
    :members:
    :undoc-members:
    :show-inheritance:

swift_scality_backend.utils module
----------------------------------

.. automodule:: swift_scality_backend.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: swift_scality_backend
    :members:
    :undoc-members:
    :show-inheritance:
